==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/sl/generic.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "to četrtletje",
	"field-quarter-short-relative+1": "naslednje četrtletje",
	"field-tue-relative+-1": "prejšnji torek",
	"field-year": "leto",
	"dateFormatItem-Hm": "HH:mm",
	"field-wed-relative+0": "to sredo",
	"field-wed-relative+1": "naslednjo sredo",
	"dateFormatItem-ms": "mm:ss",
	"field-minute": "minuta",
	"field-tue-narrow-relative+0": "ta tor.",
	"field-tue-narrow-relative+1": "nasl. tor.",
	"field-thu-short-relative+0": "ta čet.",
	"dateTimeFormat-short": "{1} {0}",
	"field-thu-short-relative+1": "naslednji čet.",
	"field-day-relative+0": "danes",
	"field-day-relative+1": "jutri",
	"field-day-relative+2": "pojutrišnjem",
	"field-wed-narrow-relative+-1": "prejš. sre.",
	"field-year-narrow": "leto",
	"field-tue-relative+0": "ta torek",
	"field-tue-relative+1": "naslednji torek",
	"field-second-short": "sek.",
	"dateFormatItem-MMMd": "d. MMM",
	"field-week-relative+0": "ta teden",
	"field-month-relative+0": "ta mesec",
	"field-week-relative+1": "naslednji teden",
	"field-month-relative+1": "naslednji mesec",
	"field-sun-narrow-relative+0": "to ned.",
	"field-mon-short-relative+0": "ta pon.",
	"field-sun-narrow-relative+1": "nasl. ned.",
	"field-mon-short-relative+1": "naslednji pon.",
	"field-second-relative+0": "zdaj",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"field-month-short": "mes.",
	"dateFormatItem-GyMMMEd": "E, d. MMM y G",
	"dateFormatItem-yyyyMd": "d. M. y G",
	"field-day": "dan",
	"field-year-relative+-1": "lani",
	"field-sat-short-relative+-1": "prejšnjo sob.",
	"field-hour-relative+0": "v tej uri",
	"dateFormatItem-yyyyMEd": "E, d. M. y G",
	"field-wed-relative+-1": "prejšnjo sredo",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "prejš. sob.",
	"field-second": "sekunda",
	"dateFormat-long": "dd. MMMM y G",
	"dateFormatItem-GyMMMd": "d. MMM y G",
	"field-quarter": "četrtletje",
	"field-week-short": "ted.",
	"field-tue-short-relative+0": "ta tor.",
	"field-tue-short-relative+1": "naslednji tor.",
	"field-mon-relative+-1": "prejšnji ponedeljek",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "mesec",
	"field-day-narrow": "dan",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "min.",
	"field-dayperiod": "dop/pop",
	"field-sat-short-relative+0": "to sob.",
	"field-sat-short-relative+1": "naslednjo sob.",
	"dateFormat-medium": "d. MMM y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"dateFormatItem-yyyyM": "M/y G",
	"field-second-narrow": "s",
	"field-mon-relative+0": "ta ponedeljek",
	"field-mon-relative+1": "naslednji ponedeljek",
	"field-year-short": "leto",
	"field-quarter-relative+-1": "zadnje četrtletje",
	"dateFormatItem-yyyyMMMd": "d. MMM y G",
	"field-sat-relative+-1": "prejšnjo soboto",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "d. M.",
	"field-hour": "ura",
	"dateFormat-full": "EEEE, dd. MMMM y G",
	"field-month-relative+-1": "prejšnji mesec",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-quarter-short": "četrtl.",
	"field-sat-narrow-relative+0": "to sob.",
	"field-fri-relative+0": "ta petek",
	"field-sat-narrow-relative+1": "nasl. sob.",
	"field-fri-relative+1": "naslednji petek",
	"field-sun-short-relative+0": "to ned.",
	"field-sun-short-relative+1": "naslednjo ned.",
	"field-week-relative+-1": "prejšnji teden",
	"field-quarter-short-relative+-1": "zadnje četrtletje",
	"field-quarter-relative+0": "to četrtletje",
	"field-minute-relative+0": "to minuto",
	"field-quarter-relative+1": "naslednje četrtletje",
	"field-wed-short-relative+-1": "prejšnjo sre.",
	"dateFormat-short": "d. MM. yy GGGGG",
	"field-thu-short-relative+-1": "prejšnji čet.",
	"dateFormatItem-yyyyMMMEd": "E, d. MMM y G",
	"field-mon-narrow-relative+-1": "prejš. pon.",
	"dateFormatItem-MMMMd": "d. MMMM",
	"field-thu-narrow-relative+-1": "prejš. čet.",
	"dateFormatItem-E": "ccc",
	"field-tue-narrow-relative+-1": "prejš. tor.",
	"dateFormatItem-H": "HH",
	"dateFormatItem-yyyy": "y G",
	"field-wed-short-relative+0": "to sre.",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+1": "naslednjo sre.",
	"field-sun-relative+-1": "prejšnjo nedeljo",
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-hm": "h:mm a",
	"dateFormatItem-d": "d",
	"field-weekday": "dan v tednu",
	"field-quarter-narrow-relative+0": "to četrtletje",
	"field-sat-relative+0": "to soboto",
	"field-quarter-narrow-relative+1": "naslednje četrtletje",
	"dateFormatItem-h": "h a",
	"field-sat-relative+1": "naslednjo soboto",
	"dateFormatItem-MEd": "E, d. MM.",
	"dateFormatItem-y": "y",
	"field-thu-narrow-relative+0": "ta čet.",
	"field-thu-narrow-relative+1": "nasl. čet.",
	"field-sun-narrow-relative+-1": "prejš. ned.",
	"field-mon-short-relative+-1": "prejšnji pon.",
	"field-thu-relative+0": "ta četrtek",
	"field-thu-relative+1": "naslednji četrtek",
	"dateFormatItem-hms": "h:mm:ss a",
	"field-fri-short-relative+-1": "prejšnji pet.",
	"field-thu-relative+-1": "prejšnji četrtek",
	"field-week": "teden",
	"dateFormatItem-Ed": "E, d.",
	"field-wed-narrow-relative+0": "to sre.",
	"field-wed-narrow-relative+1": "nasl. sre.",
	"field-quarter-narrow-relative+-1": "zadnje četrtletje",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-fri-short-relative+0": "ta pet.",
	"field-fri-short-relative+1": "naslednji pet.",
	"dateFormatItem-GyM": "M/y G",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "ura",
	"field-month-narrow": "mes.",
	"field-hour-narrow": "h",
	"field-fri-narrow-relative+-1": "prejš. pet.",
	"field-year-relative+0": "letos",
	"field-year-relative+1": "naslednje leto",
	"field-fri-relative+-1": "prejšnji petek",
	"field-tue-short-relative+-1": "prejšnji tor.",
	"field-minute-narrow": "min",
	"field-mon-narrow-relative+0": "ta pon.",
	"field-mon-narrow-relative+1": "nasl. pon.",
	"field-zone": "časovni pas",
	"dateFormatItem-MMMEd": "E, d. MMM",
	"field-quarter-narrow": "četr.",
	"field-sun-short-relative+-1": "prejšnjo ned.",
	"field-day-relative+-1": "včeraj",
	"field-day-relative+-2": "predvčerajšnjim",
	"field-sun-relative+0": "to nedeljo",
	"field-sun-relative+1": "naslednjo nedeljo",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "dan",
	"field-week-narrow": "ted.",
	"field-era": "doba",
	"field-fri-narrow-relative+0": "ta pet.",
	"field-fri-narrow-relative+1": "nasl. pet."
}
//end v1.x content
);

==> dojo_1.17.2+dfsg1.orig.tar.xz: dojo-release-1.17.2-src/dojo/cldr/nls/sl/generic.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "to četrtletje",
	"field-quarter-short-relative+1": "naslednje četrtletje",
	"field-tue-relative+-1": "prejšnji torek",
	"field-year": "leto",
	"dateFormatItem-Hm": "HH:mm",
	"field-wed-relative+0": "to sredo",
	"field-wed-relative+1": "naslednjo sredo",
	"dateFormatItem-ms": "mm:ss",
	"field-minute": "minuta",
	"field-month-narrow-relative+-1": "prejšnji mesec",
	"field-tue-narrow-relative+0": "ta tor.",
	"field-tue-narrow-relative+1": "nasl. tor.",
	"field-day-short-relative+-1": "včeraj",
	"field-thu-short-relative+0": "ta čet.",
	"dateTimeFormat-short": "{1} {0}",
	"field-day-relative+0": "danes",
	"field-day-short-relative+-2": "predvčerajšnjim",
	"field-thu-short-relative+1": "naslednji čet.",
	"field-day-relative+1": "jutri",
	"field-week-narrow-relative+0": "ta teden",
	"field-day-relative+2": "pojutrišnjem",
	"field-week-narrow-relative+1": "naslednji teden",
	"dateFormatItem-EBhms": "E h:mm:ss B",
	"field-wed-narrow-relative+-1": "prejš. sre.",
	"field-year-narrow": "leto",
	"field-era-short": "doba",
	"field-year-narrow-relative+0": "letos",
	"field-tue-relative+0": "ta torek",
	"field-year-narrow-relative+1": "naslednje leto",
	"field-tue-relative+1": "naslednji torek",
	"field-weekdayOfMonth": "dan meseca",
	"field-second-short": "sek.",
	"dateFormatItem-MMMd": "d. MMM",
	"field-weekdayOfMonth-narrow": "dan v mes.",
	"field-week-relative+0": "ta teden",
	"field-month-relative+0": "ta mesec",
	"field-week-relative+1": "naslednji teden",
	"field-month-relative+1": "naslednji mesec",
	"field-sun-narrow-relative+0": "to ned.",
	"field-mon-short-relative+0": "ta pon.",
	"field-sun-narrow-relative+1": "nasl. ned.",
	"field-mon-short-relative+1": "naslednji pon.",
	"field-second-relative+0": "zdaj",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"field-weekOfMonth": "teden meseca",
	"field-month-short": "mes.",
	"dateFormatItem-GyMMMEd": "E, d. MMM y G",
	"dateFormatItem-yyyyMd": "d. M. y G",
	"field-day": "dan",
	"field-dayOfYear-short": "dan leta",
	"field-year-relative+-1": "lani",
	"field-sat-short-relative+-1": "prejšnjo sob.",
	"field-hour-relative+0": "v tej uri",
	"dateFormatItem-yyyyMEd": "E, d. M. y G",
	"field-wed-relative+-1": "prejšnjo sredo",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "prejš. sob.",
	"field-second": "sekunda",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"dateFormat-long": "dd. MMMM y G",
	"dateFormatItem-GyMMMd": "d. MMM y G",
	"field-quarter": "četrtletje",
	"field-week-short": "ted.",
	"field-day-narrow-relative+0": "danes",
	"field-day-narrow-relative+1": "jutri",
	"field-day-narrow-relative+2": "pojutrišnjem",
	"field-tue-short-relative+0": "ta tor.",
	"field-tue-short-relative+1": "naslednji tor.",
	"field-month-short-relative+-1": "prejšnji mesec",
	"field-mon-relative+-1": "prejšnji ponedeljek",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "mesec",
	"field-day-narrow": "dan",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "min.",
	"field-dayperiod": "dop/pop",
	"field-sat-short-relative+0": "to sob.",
	"field-sat-short-relative+1": "naslednjo sob.",
	"dateFormat-medium": "d. MMM y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"dateFormatItem-yyyyM": "M/y G",
	"field-second-narrow": "s",
	"field-mon-relative+0": "ta ponedeljek",
	"field-mon-relative+1": "naslednji ponedeljek",
	"field-day-narrow-relative+-1": "včeraj",
	"field-year-short": "leto",
	"field-day-narrow-relative+-2": "predvčerajšnjim",
	"field-quarter-relative+-1": "zadnje četrtletje",
	"dateFormatItem-yyyyMMMd": "d. MMM y G",
	"field-dayperiod-narrow": "dop/pop",
	"field-week-narrow-relative+-1": "prejšnji teden",
	"field-dayOfYear": "dan leta",
	"field-sat-relative+-1": "prejšnjo soboto",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "d. M.",
	"field-hour": "ura",
	"dateFormat-full": "EEEE, dd. MMMM y G",
	"field-month-relative+-1": "prejšnji mesec",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-quarter-short": "četrtl.",
	"field-sat-narrow-relative+0": "to sob.",
	"field-fri-relative+0": "ta petek",
	"field-sat-narrow-relative+1": "nasl. sob.",
	"field-fri-relative+1": "naslednji petek",
	"dateFormatItem-EBhm": "E h:mm B",
	"field-month-narrow-relative+0": "ta mesec",
	"field-month-narrow-relative+1": "naslednji mesec",
	"field-sun-short-relative+0": "to ned.",
	"field-sun-short-relative+1": "naslednjo ned.",
	"field-week-relative+-1": "prejšnji teden",
	"field-quarter-short-relative+-1": "zadnje četrtletje",
	"dateFormatItem-Ehm": "E h:mm a",
	"field-quarter-relative+0": "to četrtletje",
	"field-minute-relative+0": "to minuto",
	"field-quarter-relative+1": "naslednje četrtletje",
	"field-wed-short-relative+-1": "prejšnjo sre.",
	"dateFormat-short": "d. MM. yy GGGGG",
	"dateFormatItem-Bh": "h B",
	"field-year-narrow-relative+-1": "lani",
	"field-thu-short-relative+-1": "prejšnji čet.",
	"dateFormatItem-yyyyMMMEd": "E, d. MMM y G",
	"field-mon-narrow-relative+-1": "prejš. pon.",
	"dateFormatItem-MMMMd": "d. MMMM",
	"field-thu-narrow-relative+-1": "prejš. čet.",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-H": "HH",
	"field-weekOfMonth-short": "ted. v mes.",
	"field-tue-narrow-relative+-1": "prejš. tor.",
	"dateFormatItem-yyyy": "y G",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+0": "to sre.",
	"field-wed-short-relative+1": "naslednjo sre.",
	"field-sun-relative+-1": "prejšnjo nedeljo",
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-hm": "h:mm a",
	"dateFormatItem-d": "d",
	"field-weekday": "dan v tednu",
	"field-day-short-relative+0": "danes",
	"field-quarter-narrow-relative+0": "to četrtletje",
	"field-day-short-relative+1": "jutri",
	"field-sat-relative+0": "to soboto",
	"field-quarter-narrow-relative+1": "naslednje četrtletje",
	"dateFormatItem-h": "h a",
	"field-day-short-relative+2": "pojutrišnjem",
	"field-sat-relative+1": "naslednjo soboto",
	"field-week-short-relative+0": "ta teden",
	"field-week-short-relative+1": "naslednji teden",
	"field-dayOfYear-narrow": "dan leta",
	"field-month-short-relative+0": "ta mesec",
	"field-month-short-relative+1": "naslednji mesec",
	"field-weekdayOfMonth-short": "dan meseca",
	"dateFormatItem-MEd": "E, d. M.",
	"field-zone-narrow": "časovni pas",
	"dateFormatItem-y": "y",
	"field-thu-narrow-relative+0": "ta čet.",
	"field-sun-narrow-relative+-1": "prejš. ned.",
	"field-mon-short-relative+-1": "prejšnji pon.",
	"field-thu-narrow-relative+1": "nasl. čet.",
	"field-thu-relative+0": "ta četrtek",
	"field-thu-relative+1": "naslednji četrtek",
	"dateFormatItem-hms": "h:mm:ss a",
	"field-fri-short-relative+-1": "prejšnji pet.",
	"field-thu-relative+-1": "prejšnji četrtek",
	"field-week": "teden",
	"dateFormatItem-Ed": "E, d.",
	"field-wed-narrow-relative+0": "to sre.",
	"field-wed-narrow-relative+1": "nasl. sre.",
	"field-quarter-narrow-relative+-1": "zadnje četrtletje",
	"field-year-short-relative+0": "letos",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-dayperiod-short": "dop/pop",
	"field-year-short-relative+1": "naslednje leto",
	"field-fri-short-relative+0": "ta pet.",
	"field-fri-short-relative+1": "naslednji pet.",
	"field-week-short-relative+-1": "prejšnji teden",
	"dateFormatItem-GyM": "M/y G",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "ura",
	"field-zone-short": "časovni pas",
	"field-month-narrow": "mes.",
	"field-hour-narrow": "h",
	"field-fri-narrow-relative+-1": "prejš. pet.",
	"field-year-relative+0": "letos",
	"field-year-relative+1": "naslednje leto",
	"field-era-narrow": "doba",
	"field-fri-relative+-1": "prejšnji petek",
	"dateFormatItem-Bhms": "h:mm:ss B",
	"field-tue-short-relative+-1": "prejšnji tor.",
	"field-minute-narrow": "min",
	"field-mon-narrow-relative+0": "ta pon.",
	"dateFormatItem-EHm": "E, HH:mm",
	"field-mon-narrow-relative+1": "nasl. pon.",
	"field-year-short-relative+-1": "lani",
	"field-zone": "časovni pas",
	"dateFormatItem-MMMEd": "E, d. MMM",
	"field-weekOfMonth-narrow": "teden meseca",
	"dateFormatItem-EHms": "E, HH:mm:ss",
	"field-weekday-narrow": "dan v tednu",
	"field-quarter-narrow": "četr.",
	"field-sun-short-relative+-1": "prejšnjo ned.",
	"field-day-relative+-1": "včeraj",
	"field-day-relative+-2": "predvčerajšnjim",
	"field-weekday-short": "dan v tednu",
	"dateFormatItem-Bhm": "h:mm B",
	"field-sun-relative+0": "to nedeljo",
	"field-sun-relative+1": "naslednjo nedeljo",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "dan",
	"field-week-narrow": "ted.",
	"field-era": "doba",
	"field-fri-narrow-relative+0": "ta pet.",
	"field-fri-narrow-relative+1": "nasl. pet."
}
//end v1.x content
);
